@@ -122,6 +122,10 @@ class Repository(GitHubCore):
 
         #: Is this repository private?
         self.private = repo.get('private')
+
+        #: Permissions for this repository
+        self.permissions = repo.get('permissions')
+
         #: ``datetime`` object representing the last time commits were pushed
         #: to the repository.
         self.pushed_at = self._strptime(repo.get('pushed_at'))
@@ -782,7 +786,7 @@ class Repository(GitHubCore):
         return Release(json, self)
 
     @requires_auth
-    def create_status(self, sha, state, target_url='', description=''):
+    def create_status(self, sha, state, target_url='', description='', context=''):
         """Create a status object on a commit.
 
         :param str sha: (required), SHA of the commit to create the status on
@@ -794,7 +798,7 @@ class Repository(GitHubCore):
         json = {}
         if sha and state:
             data = {'state': state, 'target_url': target_url,
-                    'description': description}
+                    'description': description, 'context': context}
             url = self._build_url('statuses', sha, base_url=self._api)
             json = self._json(self._post(url, data=data), 201)
         return Status(json) if json else None
